@@ -6,6 +6,8 @@ import json
 from nonebot.adapters.onebot.v11.helpers import extract_image_urls as geturls
 import httpx
 from nonebot_plugin_Imagelabels.Download import Downloading
+from nonebot_plugin_Imagelabels.recover import Recover
+from time import asctime as now_time
 
 system_name = os.name
 parameter = os.path.exists('parameter.json')
@@ -86,9 +88,16 @@ async def Make(sumber, yolov5_Path, Save_as):
     elif system_name == 'posix':
         image_path = 'Target_picture/'+Save_as + str(sumber) + '.png'
         detect_path = yolov5_Path + '/detect.py'
-
-    shell = f'python {detect_path} --source ./{image_path}'
-    os.system(shell)
+    try:
+        shell = f'python {detect_path} --source ./{image_path}'
+        os.system(shell)
+    except Exception as err:
+        with open('Imagelabels-err.txt', mode='a+', encoding='utf-8') as err:
+                err.write(str(now_time()) + ':' + str(err))
+        print('发生错误，可能是由于无法下载yolov5s导致的 错误代码 002 已将错误追加到Imagelabels-err.txt \n An error has occurred, possibly due to failure to download yolov5s Error code 002 The error has been appended to the Imagelabels-err .txt')
+        Recover.recover(Pictures_folder,parameter,parameter_json,yolov5_Path,system_name)
+        print('已恢复所有配置文件以保证运行 \n All configuration files have been restored to guarantee operation')
+        
     if int(sumber) == 1:
         if system_name == 'nt':
             Finished_picture_path = yolov5_Path + \
@@ -106,3 +115,10 @@ async def Make(sumber, yolov5_Path, Save_as):
                 f'/runs/detect/exp{sumber}/' + Save_as + str(sumber) + '.png'
     print(Finished_picture_path)
     await trigger.send(MessageSegment.image('file:///'+Finished_picture_path))
+
+recover = on_command('恢复默认')
+@recover.handle()
+async def recover_():
+    Recover.recover(Pictures_folder,parameter,parameter_json,yolov5_Path,system_name)
+    await recover.send('已恢复默认值')
+
